==> ui-18.0.4.tgz: package/components/image/ImagePreview.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import { useEffect, useRef, useState } from 'react';
import ReactDOM from 'react-dom';
import { useEvent, useImmer, useIsomorphicLayoutEffect, useLockScroll, useRefExtra } from '@react-devui/hooks';
import { CloseOutlined, LeftOutlined, RightOutlined, RotateRightOutlined, ZoomInOutlined, ZoomOutOutlined } from '@react-devui/icons';
import { getClassName } from '@react-devui/utils';
import { useDValue, useMaxIndex } from '../../hooks';
import { registerComponentMate, TTANSITION_DURING_BASE } from '../../utils';
import { DMask } from '../_mask';
import { DTransition } from '../_transition';
import { DButton } from '../button';
import { DInput } from '../input';
import { useComponentConfig, usePrefixConfig } from '../root';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DImage.Preview' });
export function DImagePreview(props) {
    var _a, _b, _c;
    const _d = useComponentConfig(COMPONENT_NAME, props), { dList, dActive, dVisible, dZIndex, dMask = true, dMaskClosable = true, dEscClosable = true, onActiveChange, onClose, afterVisibleChange } = _d, restProps = __rest(_d, ["dList", "dActive", "dVisible", "dZIndex", "dMask", "dMaskClosable", "dEscClosable", "onActiveChange", "onClose", "afterVisibleChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    //#region Ref
    const previewRef = useRef(null);
    const containerRef = useRefExtra(() => {
        let el = document.getElementById(`${dPrefix}image-preview-root`);
        if (!el) {
            el = document.createElement('div');
            el.id = `${dPrefix}image-preview-root`;
            document.body.appendChild(el);
        }
        return el;
    }, true);
    const windowRef = useRefExtra(() => window);
    //#endregion
    const dataRef = useRef({
        prevActiveEl: null,
        eventData: {},
    });
    const [activeIndex, changeActiveIndex] = useDValue(0, dActive, onActiveChange);
    const activeSrc = dList[activeIndex].src;
    const [offset, setOffset] = useState(3);
    let startIndex = Math.max(activeIndex - offset, 0);
    const endIndex = Math.min(startIndex + offset * 2, dList.length - 1);
    startIndex = Math.max(endIndex - offset * 2, 0);
    const [isDragging, setIsDragging] = useState(false);
    const [position, setPosition] = useImmer(new Map());
    const activePosition = (_a = position.get(activeSrc)) !== null && _a !== void 0 ? _a : { top: 0, left: 0 };
    const [rotate, setRotate] = useImmer(new Map());
    const activeRotate = (_b = rotate.get(activeSrc)) !== null && _b !== void 0 ? _b : 0;
    const [scale, setScale] = useImmer(new Map());
    const activeScale = (_c = scale.get(activeSrc)) !== null && _c !== void 0 ? _c : 1;
    const [visible, changeVisible] = useDValue(false, dVisible, onClose);
    const maxZIndex = useMaxIndex(visible);
    const zIndex = (() => {
        if (!isUndefined(dZIndex)) {
            return dZIndex;
        }
        return maxZIndex;
    })();
    const getOffset = () => {
        setOffset(~~((window.innerWidth - 108) / 120));
    };
    useIsomorphicLayoutEffect(() => {
        getOffset();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    useEvent(windowRef, 'resize', getOffset, {}, !visible);
    const handleMove = () => {
        const { initMove, currentMove, initScale, currentScale } = dataRef.current.eventData;
        if (initMove && currentMove) {
            const movementX = currentMove.x - initMove.x;
            const movementY = currentMove.y - initMove.y;
            setPosition((draft) => {
                var _a;
                const oldPosition = (_a = draft.get(activeSrc)) !== null && _a !== void 0 ? _a : { top: 0, left: 0 };
                draft.set(activeSrc, {
                    top: oldPosition.top + movementY,
                    left: oldPosition.left + movementX,
                });
            });
            dataRef.current.eventData.initMove = currentMove;
            dataRef.current.eventData.currentMove = undefined;
        }
        if (initScale && currentScale) {
            const initLength = Math.sqrt(Math.pow(initScale.x0 - initScale.x1, 2) + Math.pow(initScale.y0 - initScale.y1, 2));
            const currentLength = Math.sqrt(Math.pow(currentScale.x0 - currentScale.x1, 2) + Math.pow(currentScale.y0 - currentScale.y1, 2));
            setScale((draft) => {
                var _a;
                const oldScale = (_a = draft.get(activeSrc)) !== null && _a !== void 0 ? _a : 1;
                draft.set(activeSrc, Math.max(oldScale + (currentLength - initLength) / 100, 1));
            });
            dataRef.current.eventData.initScale = currentScale;
            dataRef.current.eventData.currentScale = undefined;
        }
    };
    useLockScroll(visible);
    useEffect(() => {
        if (visible) {
            dataRef.current.prevActiveEl = document.activeElement;
            if (previewRef.current) {
                previewRef.current.focus({ preventScroll: true });
            }
        }
        else if (dataRef.current.prevActiveEl) {
            dataRef.current.prevActiveEl.focus({ preventScroll: true });
        }
    }, [visible]);
    const listenDragEvent = visible && isDragging;
    useEvent(windowRef, 'touchmove', (e) => {
        e.preventDefault();
        if (e.touches.length === 2) {
            dataRef.current.eventData.initMove = dataRef.current.eventData.currentMove = undefined;
            const newScale = {
                x0: e.touches[0].clientX,
                y0: e.touches[0].clientY,
                x1: e.touches[1].clientX,
                y1: e.touches[1].clientY,
            };
            if (isUndefined(dataRef.current.eventData.initScale)) {
                dataRef.current.eventData.initScale = newScale;
            }
            else {
                dataRef.current.eventData.currentScale = newScale;
            }
        }
        else {
            dataRef.current.eventData.initScale = dataRef.current.eventData.currentScale = undefined;
            const newMove = {
                x: e.touches[0].clientX,
                y: e.touches[0].clientY,
            };
            if (isUndefined(dataRef.current.eventData.initMove)) {
                dataRef.current.eventData.initMove = newMove;
            }
            else {
                dataRef.current.eventData.currentMove = newMove;
            }
        }
        handleMove();
    }, { passive: false }, !listenDragEvent);
    useEvent(windowRef, 'mousemove', (e) => {
        e.preventDefault();
        const newMove = {
            x: e.clientX,
            y: e.clientY,
        };
        if (isUndefined(dataRef.current.eventData.initMove)) {
            dataRef.current.eventData.initMove = newMove;
        }
        else {
            dataRef.current.eventData.currentMove = newMove;
        }
        handleMove();
    }, {}, !listenDragEvent);
    useEvent(windowRef, 'mouseup', () => {
        setIsDragging(false);
    }, {}, !listenDragEvent);
    return (containerRef.current &&
        ReactDOM.createPortal(_jsx(DTransition, Object.assign({ dIn: visible, dDuring: TTANSITION_DURING_BASE, dDestroyWhenLeaved: true, afterEnter: () => {
                afterVisibleChange === null || afterVisibleChange === void 0 ? void 0 : afterVisibleChange(true);
            }, afterLeave: () => {
                afterVisibleChange === null || afterVisibleChange === void 0 ? void 0 : afterVisibleChange(false);
            } }, { children: (state) => {
                let transitionStyle = {};
                switch (state) {
                    case 'enter':
                        transitionStyle = { transform: 'scale(0.3)', opacity: 0 };
                        break;
                    case 'entering':
                        transitionStyle = {
                            transition: ['transform', 'opacity'].map((attr) => `${attr} ${TTANSITION_DURING_BASE}ms ease-out`).join(', '),
                        };
                        break;
                    case 'leaving':
                        transitionStyle = {
                            transform: 'scale(0.3)',
                            opacity: 0,
                            transition: ['transform', 'opacity'].map((attr) => `${attr} ${TTANSITION_DURING_BASE}ms ease-in`).join(', '),
                        };
                        break;
                    default:
                        break;
                }
                return (_jsxs("div", Object.assign({}, restProps, { ref: previewRef, className: getClassName(restProps.className, `${dPrefix}image-preview`), style: Object.assign(Object.assign(Object.assign({}, restProps.style), { display: state === 'leaved' ? 'none' : undefined, zIndex }), transitionStyle), tabIndex: -1, onKeyDown: (e) => {
                        if (dEscClosable && e.code === 'Escape') {
                            changeVisible(false);
                        }
                    } }, { children: [_jsx("button", Object.assign({ className: getClassName(`${dPrefix}image-preview__navigation-button`, `${dPrefix}image-preview__navigation-button--prev`), onClick: () => {
                                changeActiveIndex((prevActiveIndex) => {
                                    return prevActiveIndex === 0 ? dList.length - 1 : prevActiveIndex - 1;
                                });
                            } }, { children: _jsx(LeftOutlined, {}) })), _jsx("button", Object.assign({ className: getClassName(`${dPrefix}image-preview__navigation-button`, `${dPrefix}image-preview__navigation-button--next`), onClick: () => {
                                changeActiveIndex((prevActiveIndex) => {
                                    return prevActiveIndex === dList.length - 1 ? 0 : prevActiveIndex + 1;
                                });
                            } }, { children: _jsx(RightOutlined, {}) })), _jsxs("ul", Object.assign({ className: `${dPrefix}image-preview__toolbar` }, { children: [_jsxs("li", Object.assign({ className: `${dPrefix}image-preview__toolbar-page` }, { children: [_jsx(DInput, { className: `${dPrefix}image-preview__toolbar-page-input`, dModel: (activeIndex + 1).toString(), dType: "number", dSize: "smaller", dMin: 1, dMax: dList.length, dInteger: true, onModelChange: (val) => {
                                                if (val) {
                                                    changeActiveIndex(Number(val) - 1);
                                                }
                                            } }), _jsx("span", { children: "/" }), _jsx("span", { children: dList.length })] })), _jsx("li", Object.assign({ className: `${dPrefix}image-preview__toolbar-rotate` }, { children: _jsx(DButton, { onClick: () => {
                                            setRotate((draft) => {
                                                var _a;
                                                const oldRotate = (_a = draft.get(activeSrc)) !== null && _a !== void 0 ? _a : 0;
                                                draft.set(activeSrc, oldRotate + 90);
                                            });
                                        }, dType: "text", dIcon: _jsx(RotateRightOutlined, {}) }) })), _jsx("li", Object.assign({ className: `${dPrefix}image-preview__toolbar-zoom-out` }, { children: _jsx(DButton, { onClick: () => {
                                            setScale((draft) => {
                                                var _a;
                                                const oldScale = (_a = draft.get(activeSrc)) !== null && _a !== void 0 ? _a : 1;
                                                draft.set(activeSrc, Math.max(oldScale / 1.3, 1));
                                            });
                                        }, dType: "text", dIcon: _jsx(ZoomOutOutlined, {}) }) })), _jsx("li", Object.assign({ className: `${dPrefix}image-preview__toolbar-zoom` }, { children: _jsx(DInput, { className: `${dPrefix}image-preview__toolbar-zoom-input`, dModel: Math.round(activeScale * 100).toString(), dType: "number", dSize: "smaller", dMin: 100, dStep: 10, dInteger: true, onModelChange: (val) => {
                                            if (val) {
                                                setScale((draft) => {
                                                    draft.set(activeSrc, Number(val) / 100);
                                                });
                                            }
                                        } }) })), _jsx("li", Object.assign({ className: `${dPrefix}image-preview__toolbar-zoom-in` }, { children: _jsx(DButton, { onClick: () => {
                                            setScale((draft) => {
                                                var _a;
                                                const oldScale = (_a = draft.get(activeSrc)) !== null && _a !== void 0 ? _a : 1;
                                                draft.set(activeSrc, oldScale * 1.3);
                                            });
                                        }, dType: "text", dIcon: _jsx(ZoomInOutlined, {}) }) })), _jsx("li", Object.assign({ className: `${dPrefix}image-preview__toolbar-close` }, { children: _jsx(DButton, { onClick: () => {
                                            changeVisible(false);
                                        }, dType: "text", dIcon: _jsx(CloseOutlined, {}) }) }))] })), 
                        // eslint-disable-next-line jsx-a11y/alt-text
                        _jsx("img", Object.assign({}, dList[activeIndex], { className: `${dPrefix}image-preview__img`, style: {
                                transform: `translate(${activePosition.left}px, ${activePosition.top}px) rotate(${activeRotate}deg) scale(${activeScale})`,
                            }, width: undefined, height: undefined, tabIndex: -1, onMouseDown: (e) => {
                                if (e.button === 0) {
                                    e.preventDefault();
                                    e.currentTarget.focus({ preventScroll: true });
                                    dataRef.current.eventData = {};
                                    setIsDragging(true);
                                }
                            }, onMouseUp: (e) => {
                                if (e.button === 0) {
                                    e.preventDefault();
                                }
                            }, onTouchStart: (e) => {
                                e.currentTarget.focus({ preventScroll: true });
                                dataRef.current.eventData = {};
                                setIsDragging(true);
                            }, onTouchEnd: () => {
                                setIsDragging(false);
                            }, onWheel: (e) => {
                                setScale((draft) => {
                                    var _a;
                                    const oldScale = (_a = draft.get(activeSrc)) !== null && _a !== void 0 ? _a : 1;
                                    draft.set(activeSrc, e.deltaY < 0 ? oldScale + 0.1 : Math.max(oldScale - 0.1, 1));
                                });
                            } })), _jsx("ul", Object.assign({ className: `${dPrefix}image-preview__thumbnail-list` }, { children: dList.map((imgProps, index) => index >= startIndex &&
                                index <= endIndex && (_jsx("li", Object.assign({ className: getClassName(`${dPrefix}image-preview__thumbnail`, {
                                    'is-active': activeIndex === index,
                                }), onClick: () => {
                                    changeActiveIndex(index);
                                } }, { children: 
                                // eslint-disable-next-line jsx-a11y/alt-text
                                _jsx("img", Object.assign({}, imgProps, { className: `${dPrefix}image-preview__thumbnail-img`, style: undefined, width: undefined, height: undefined })) }), index))) })), dMask && (_jsx(DMask, { dVisible: true, onClose: () => {
                                if (dMaskClosable) {
                                    changeVisible(false);
                                }
                            } }))] })));
            } })), containerRef.current));
}

==> ui-18.3.1.tgz: package/components/image/ImagePreview.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import { useEffect, useRef, useState } from 'react';
import ReactDOM from 'react-dom';
import { useEvent, useImmer, useIsomorphicLayoutEffect, useLockScroll, useRefExtra } from '@react-devui/hooks';
import { CloseOutlined, LeftOutlined, RightOutlined, RotateRightOutlined, ZoomInOutlined, ZoomOutOutlined } from '@react-devui/icons';
import { getClassName } from '@react-devui/utils';
import { useDValue, useMaxIndex } from '../../hooks';
import { registerComponentMate, TTANSITION_DURING_BASE } from '../../utils';
import { DMask } from '../_mask';
import { DTransition } from '../_transition';
import { DButton } from '../button';
import { DInput } from '../input';
import { useComponentConfig, usePrefixConfig } from '../root';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DImage.Preview' });
export function DImagePreview(props) {
    var _a, _b, _c;
    const _d = useComponentConfig(COMPONENT_NAME, props), { dList, dActive, dVisible, dZIndex, dEscClosable = true, onActiveChange, onClose, afterVisibleChange } = _d, restProps = __rest(_d, ["dList", "dActive", "dVisible", "dZIndex", "dEscClosable", "onActiveChange", "onClose", "afterVisibleChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    //#region Ref
    const previewRef = useRef(null);
    const containerRef = useRefExtra(() => {
        let el = document.getElementById(`${dPrefix}image-preview-root`);
        if (!el) {
            el = document.createElement('div');
            el.id = `${dPrefix}image-preview-root`;
            document.body.appendChild(el);
        }
        return el;
    }, true);
    const windowRef = useRefExtra(() => window);
    //#endregion
    const dataRef = useRef({
        prevActiveEl: null,
        eventData: {},
    });
    const [activeIndex, changeActiveIndex] = useDValue(0, dActive, onActiveChange);
    const activeSrc = dList[activeIndex].src;
    const [offset, setOffset] = useState(3);
    let startIndex = Math.max(activeIndex - offset, 0);
    const endIndex = Math.min(startIndex + offset * 2, dList.length - 1);
    startIndex = Math.max(endIndex - offset * 2, 0);
    const [isDragging, setIsDragging] = useState(false);
    const [position, setPosition] = useImmer(new Map());
    const activePosition = (_a = position.get(activeSrc)) !== null && _a !== void 0 ? _a : { top: 0, left: 0 };
    const [rotate, setRotate] = useImmer(new Map());
    const activeRotate = (_b = rotate.get(activeSrc)) !== null && _b !== void 0 ? _b : 0;
    const [scale, setScale] = useImmer(new Map());
    const activeScale = (_c = scale.get(activeSrc)) !== null && _c !== void 0 ? _c : 1;
    const [visible, changeVisible] = useDValue(false, dVisible, onClose);
    const maxZIndex = useMaxIndex(visible);
    const zIndex = (() => {
        if (!isUndefined(dZIndex)) {
            return dZIndex;
        }
        return maxZIndex;
    })();
    const getOffset = () => {
        setOffset(~~((window.innerWidth - 108) / 120));
    };
    useIsomorphicLayoutEffect(() => {
        getOffset();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    useEvent(windowRef, 'resize', getOffset, {}, !visible);
    const handleMove = () => {
        const { initMove, currentMove, initScale, currentScale } = dataRef.current.eventData;
        if (initMove && currentMove) {
            const movementX = currentMove.x - initMove.x;
            const movementY = currentMove.y - initMove.y;
            setPosition((draft) => {
                var _a;
                const oldPosition = (_a = draft.get(activeSrc)) !== null && _a !== void 0 ? _a : { top: 0, left: 0 };
                draft.set(activeSrc, {
                    top: oldPosition.top + movementY,
                    left: oldPosition.left + movementX,
                });
            });
            dataRef.current.eventData.initMove = currentMove;
            dataRef.current.eventData.currentMove = undefined;
        }
        if (initScale && currentScale) {
            const initLength = Math.sqrt(Math.pow(initScale.x0 - initScale.x1, 2) + Math.pow(initScale.y0 - initScale.y1, 2));
            const currentLength = Math.sqrt(Math.pow(currentScale.x0 - currentScale.x1, 2) + Math.pow(currentScale.y0 - currentScale.y1, 2));
            setScale((draft) => {
                var _a;
                const oldScale = (_a = draft.get(activeSrc)) !== null && _a !== void 0 ? _a : 1;
                draft.set(activeSrc, Math.max(oldScale + (currentLength - initLength) / 100, 1));
            });
            dataRef.current.eventData.initScale = currentScale;
            dataRef.current.eventData.currentScale = undefined;
        }
    };
    useLockScroll(visible);
    useEffect(() => {
        if (visible) {
            dataRef.current.prevActiveEl = document.activeElement;
            if (previewRef.current) {
                previewRef.current.focus({ preventScroll: true });
            }
        }
        else if (dataRef.current.prevActiveEl) {
            dataRef.current.prevActiveEl.focus({ preventScroll: true });
        }
    }, [visible]);
    const listenDragEvent = visible && isDragging;
    useEvent(windowRef, 'touchmove', (e) => {
        e.preventDefault();
        if (e.touches.length === 2) {
            dataRef.current.eventData.initMove = dataRef.current.eventData.currentMove = undefined;
            const newScale = {
                x0: e.touches[0].clientX,
                y0: e.touches[0].clientY,
                x1: e.touches[1].clientX,
                y1: e.touches[1].clientY,
            };
            if (isUndefined(dataRef.current.eventData.initScale)) {
                dataRef.current.eventData.initScale = newScale;
            }
            else {
                dataRef.current.eventData.currentScale = newScale;
            }
        }
        else {
            dataRef.current.eventData.initScale = dataRef.current.eventData.currentScale = undefined;
            const newMove = {
                x: e.touches[0].clientX,
                y: e.touches[0].clientY,
            };
            if (isUndefined(dataRef.current.eventData.initMove)) {
                dataRef.current.eventData.initMove = newMove;
            }
            else {
                dataRef.current.eventData.currentMove = newMove;
            }
        }
        handleMove();
    }, { passive: false }, !listenDragEvent);
    useEvent(windowRef, 'mousemove', (e) => {
        e.preventDefault();
        const newMove = {
            x: e.clientX,
            y: e.clientY,
        };
        if (isUndefined(dataRef.current.eventData.initMove)) {
            dataRef.current.eventData.initMove = newMove;
        }
        else {
            dataRef.current.eventData.currentMove = newMove;
        }
        handleMove();
    }, {}, !listenDragEvent);
    useEvent(windowRef, 'mouseup', () => {
        setIsDragging(false);
    }, {}, !listenDragEvent);
    return (containerRef.current &&
        ReactDOM.createPortal(_jsx(DTransition, Object.assign({ dIn: visible, dDuring: TTANSITION_DURING_BASE, dDestroyWhenLeaved: true, afterEnter: () => {
                afterVisibleChange === null || afterVisibleChange === void 0 ? void 0 : afterVisibleChange(true);
            }, afterLeave: () => {
                afterVisibleChange === null || afterVisibleChange === void 0 ? void 0 : afterVisibleChange(false);
            } }, { children: (state) => {
                let transitionStyle = {};
                switch (state) {
                    case 'enter':
                        transitionStyle = { transform: 'scale(0.3)', opacity: 0 };
                        break;
                    case 'entering':
                        transitionStyle = {
                            transition: ['transform', 'opacity'].map((attr) => `${attr} ${TTANSITION_DURING_BASE}ms ease-out`).join(', '),
                        };
                        break;
                    case 'leaving':
                        transitionStyle = {
                            transform: 'scale(0.3)',
                            opacity: 0,
                            transition: ['transform', 'opacity'].map((attr) => `${attr} ${TTANSITION_DURING_BASE}ms ease-in`).join(', '),
                        };
                        break;
                    default:
                        break;
                }
                return (_jsxs("div", Object.assign({}, restProps, { ref: previewRef, className: getClassName(restProps.className, `${dPrefix}image-preview`), style: Object.assign(Object.assign(Object.assign({}, restProps.style), { display: state === 'leaved' ? 'none' : undefined, zIndex }), transitionStyle), tabIndex: -1, onKeyDown: (e) => {
                        if (dEscClosable && e.code === 'Escape') {
                            changeVisible(false);
                        }
                    } }, { children: [_jsx("button", Object.assign({ className: getClassName(`${dPrefix}image-preview__navigation-button`, `${dPrefix}image-preview__navigation-button--prev`), onClick: () => {
                                changeActiveIndex((prevActiveIndex) => {
                                    return prevActiveIndex === 0 ? dList.length - 1 : prevActiveIndex - 1;
                                });
                            } }, { children: _jsx(LeftOutlined, {}) })), _jsx("button", Object.assign({ className: getClassName(`${dPrefix}image-preview__navigation-button`, `${dPrefix}image-preview__navigation-button--next`), onClick: () => {
                                changeActiveIndex((prevActiveIndex) => {
                                    return prevActiveIndex === dList.length - 1 ? 0 : prevActiveIndex + 1;
                                });
                            } }, { children: _jsx(RightOutlined, {}) })), _jsxs("ul", Object.assign({ className: `${dPrefix}image-preview__toolbar` }, { children: [_jsxs("li", Object.assign({ className: `${dPrefix}image-preview__toolbar-page` }, { children: [_jsx(DInput, { className: `${dPrefix}image-preview__toolbar-page-input`, dModel: (activeIndex + 1).toString(), dType: "number", dSize: "smaller", dMin: 1, dMax: dList.length, dInteger: true, onModelChange: (val) => {
                                                if (val) {
                                                    changeActiveIndex(Number(val) - 1);
                                                }
                                            } }), _jsx("span", { children: "/" }), _jsx("span", { children: dList.length })] })), _jsx("li", Object.assign({ className: `${dPrefix}image-preview__toolbar-rotate` }, { children: _jsx(DButton, { onClick: () => {
                                            setRotate((draft) => {
                                                var _a;
                                                const oldRotate = (_a = draft.get(activeSrc)) !== null && _a !== void 0 ? _a : 0;
                                                draft.set(activeSrc, oldRotate + 90);
                                            });
                                        }, dType: "text", dIcon: _jsx(RotateRightOutlined, {}) }) })), _jsx("li", Object.assign({ className: `${dPrefix}image-preview__toolbar-zoom-out` }, { children: _jsx(DButton, { onClick: () => {
                                            setScale((draft) => {
                                                var _a;
                                                const oldScale = (_a = draft.get(activeSrc)) !== null && _a !== void 0 ? _a : 1;
                                                draft.set(activeSrc, Math.max(oldScale / 1.3, 1));
                                            });
                                        }, dType: "text", dIcon: _jsx(ZoomOutOutlined, {}) }) })), _jsx("li", Object.assign({ className: `${dPrefix}image-preview__toolbar-zoom` }, { children: _jsx(DInput, { className: `${dPrefix}image-preview__toolbar-zoom-input`, dModel: Math.round(activeScale * 100).toString(), dType: "number", dSize: "smaller", dMin: 100, dStep: 10, dInteger: true, onModelChange: (val) => {
                                            if (val) {
                                                setScale((draft) => {
                                                    draft.set(activeSrc, Number(val) / 100);
                                                });
                                            }
                                        } }) })), _jsx("li", Object.assign({ className: `${dPrefix}image-preview__toolbar-zoom-in` }, { children: _jsx(DButton, { onClick: () => {
                                            setScale((draft) => {
                                                var _a;
                                                const oldScale = (_a = draft.get(activeSrc)) !== null && _a !== void 0 ? _a : 1;
                                                draft.set(activeSrc, oldScale * 1.3);
                                            });
                                        }, dType: "text", dIcon: _jsx(ZoomInOutlined, {}) }) })), _jsx("li", Object.assign({ className: `${dPrefix}image-preview__toolbar-close` }, { children: _jsx(DButton, { onClick: () => {
                                            changeVisible(false);
                                        }, dType: "text", dIcon: _jsx(CloseOutlined, {}) }) }))] })), 
                        // eslint-disable-next-line jsx-a11y/alt-text
                        _jsx("img", Object.assign({}, dList[activeIndex], { className: `${dPrefix}image-preview__img`, style: {
                                transform: `translate(${activePosition.left}px, ${activePosition.top}px) rotate(${activeRotate}deg) scale(${activeScale})`,
                            }, width: undefined, height: undefined, tabIndex: -1, onMouseDown: (e) => {
                                if (e.button === 0) {
                                    e.preventDefault();
                                    e.currentTarget.focus({ preventScroll: true });
                                    dataRef.current.eventData = {};
                                    setIsDragging(true);
                                }
                            }, onMouseUp: (e) => {
                                if (e.button === 0) {
                                    e.preventDefault();
                                }
                            }, onTouchStart: (e) => {
                                e.currentTarget.focus({ preventScroll: true });
                                dataRef.current.eventData = {};
                                setIsDragging(true);
                            }, onTouchEnd: () => {
                                setIsDragging(false);
                            }, onWheel: (e) => {
                                setScale((draft) => {
                                    var _a;
                                    const oldScale = (_a = draft.get(activeSrc)) !== null && _a !== void 0 ? _a : 1;
                                    draft.set(activeSrc, e.deltaY < 0 ? oldScale + 0.1 : Math.max(oldScale - 0.1, 1));
                                });
                            } })), _jsx("ul", Object.assign({ className: `${dPrefix}image-preview__thumbnail-list` }, { children: dList.map((imgProps, index) => index >= startIndex &&
                                index <= endIndex && (_jsx("li", Object.assign({ className: getClassName(`${dPrefix}image-preview__thumbnail`, {
                                    'is-active': activeIndex === index,
                                }), onClick: () => {
                                    changeActiveIndex(index);
                                } }, { children: 
                                // eslint-disable-next-line jsx-a11y/alt-text
                                _jsx("img", Object.assign({}, imgProps, { className: `${dPrefix}image-preview__thumbnail-img`, style: undefined, width: undefined, height: undefined })) }), index))) })), _jsx(DMask, { dVisible: true, onClose: undefined })] })));
            } })), containerRef.current));
}
